# rRNAFinder
A python tool for identify rRNA gene in plant genome.

## Installation
This package depended on ncbi blast, you should install it first.

Install rRNAFinder with pip:
```
pip install rRNAFinder
```

## Usage

```
```

## Example
```
```